==> eid-mw-4.2.5.tar.gz: eid-mw-4.2.5/doc/sdk/examples/CS/EidSamples/Program.cs <==
﻿/* ****************************************************************************

 * eID Middleware Project.
 * Copyright (C) 2010-2010 FedICT.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version
 * 3.0 as published by the Free Software Foundation.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, see
 * http://www.gnu.org/licenses/.

**************************************************************************** */
using System.Collections.Generic;
using System;
using System.Security.Cryptography.X509Certificates;
using EidSamples.tests;

namespace EidSamples
{
    class Program
    {
        static void Main(string[] args)
        {
            //System.Diagnostics.Stopwatch duurtijd = new System.Diagnostics.Stopwatch();
            //duurtijd.Start();
            DataTests dt = new DataTests();
            SignTests st = new SignTests();
            IntegrityTests it = new IntegrityTests();
            //dt.StoreCertificateRNFile();
            //dt.GetSpecialStatus();

           // it.IntegrityIdentityFile();
            //st.SignSignature();
 //           CertificateValidityTests ct = new CertificateValidityTests();
  //          ct.ValidityAuthenticationChain();
            dt.GetSurname();
            /*dt.GetSurname();
            IntegrityIdentityFile
            dt.GetSurname();
            dt.GetSurname();
            dt.GetSurname();
            dt.GetSurname();
            dt.GetSurname();
            dt.GetSurname();
            dt.GetSurname();
            dt.GetCertificateLabels();*/
            //duurtijd.Stop();
           // Console.WriteLine(duurtijd.ElapsedMilliseconds.ToString());
        }
    }
}

==> eid-mw-5.1.15.tar.gz: eid-mw-5.1.15/doc/sdk/examples/CS/EidSamples/Program.cs <==
﻿/* ****************************************************************************

 * eID Middleware Project.
 * Copyright (C) 2010-2010 FedICT.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version
 * 3.0 as published by the Free Software Foundation.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, see
 * http://www.gnu.org/licenses/.

**************************************************************************** */
using System.Collections.Generic;
using System;
using System.Security.Cryptography.X509Certificates;
using EidSamples.tests;

namespace EidSamples
{
    class Program
    {
        static void Main(string[] args)
        {
            //System.Diagnostics.Stopwatch duurtijd = new System.Diagnostics.Stopwatch();
            //duurtijd.Start();
            DataTests dt = new DataTests();
            SignTests st = new SignTests();
            IntegrityTests it = new IntegrityTests();
            //dt.StoreCertificateRNFile();
            //dt.GetSpecialStatus();
     
            //it.IntegrityIdentityFile();
            it.IntegrityAddressFile();
            //st.SignSignature();
            //           CertificateValidityTests ct = new CertificateValidityTests();
            //          ct.ValidityAuthenticationChain();
            //dt.GetSurname();
            /*dt.GetSurname();
            IntegrityIdentityFile
            dt.GetSurname();
            dt.GetSurname();
            dt.GetSurname();
            dt.GetSurname();
            dt.GetSurname();
            dt.GetSurname();
            dt.GetSurname();
            dt.GetCertificateLabels();
            st.SignAuthentication();*/
            //st.ChallengeCard();
            //duurtijd.Stop();
            // Console.WriteLine(duurtijd.ElapsedMilliseconds.ToString());
        }
    }
}
